@@ -2,6 +2,7 @@ from acceldata_sdk.torch_client import TorchClient
 import acceldata_sdk.constants as const
 from acceldata_sdk.models.tags import AssetLabel
 from acceldata_sdk.models.profile import ProfilingType
+from acceldata_sdk.models.assetType import AssetType
 from acceldata_sdk.models.profile import AutoProfileConfiguration, Profile, ProfileRequest, ProfilingType
 import pprint
 
@@ -14,7 +15,19 @@ pp = pprint.PrettyPrinter(indent=4)
 # torchClient = TorchClient(url="https://winterfel.qetest.acceldata.dev", access_key="S58A3VBB7L3T5PZ",
 #                           secret_key="51YPWKNLXOUZMI4QTTKIPRKYQBZX9W",do_version_check=False)
 #
-# torchClient.get_datasource("SnowflakeProd",False)
+torchClient = TorchClient(url="https://torchtenant.unified.acceldata.tech", access_key="TXU3N9MDGN7ZIZD",
+                                  secret_key="OGWX9ONR37CQFKL2EL7S4NBKPY433G", do_version_check=False)
+torch_credentials = {
+    'url': 'https://torch.acceldata.local:5443/torch',
+    'access_key': 'P04IM8FNQRUCRTU',
+    'secret_key': 'E6LL9YUPMG4BDTJHT2VZD75HW0B8E5',
+    'do_version_check': 'True'
+}
+torchClient = TorchClient(**torch_credentials)
+assemblyName = "COMPUTE_WH"
+torchClient.get_datasource(assemblyName,False)
+torchClient.get_datasource(const.AssetSourceType.SNOWFLAKE)
+exit()
 # base_path = 's3a://demo-data-plane-one/execution_result'
 # good_data_location = 's3a://demo-data-plane-one/execution_result/2022-09-29/segmented_cc/_1664445283208/successrecords'
 # stage_path_suffix=good_data_location.lstrip(base_path)
